==> mediawiki-1.25.2.tar.gz: mediawiki-1.25.2/extensions/CiteThisPage/CiteThisPage.alias.php <==
<?php
/**
 * Aliases for Special:CiteThisPage
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'CiteThisPage' => array( 'CiteThisPage', 'Cite' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'CiteThisPage' => array( 'استشهاد' ),
);

/** Egyptian Spoken Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'CiteThisPage' => array( 'استشهاد' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'CiteThisPage' => array( 'উদ্ধৃতি' ),
);

/** Avaric (авар) */
$specialPageAliases['av'] = array(
	'CiteThisPage' => array( 'Цитата' ),
);

/** Bikol Central (Bikol Central) */
$specialPageAliases['bcl'] = array(
	'CiteThisPage' => array( 'Sambitón' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'CiteThisPage' => array( 'Цитиране' ),
);

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = array(
	'CiteThisPage' => array( 'یات_کورت' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'CiteThisPage' => array( 'Juhut' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'CiteThisPage' => array( 'Menegiñ' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'CiteThisPage' => array( 'Citiraj' ),
);

/** буряад (буряад) */
$specialPageAliases['bxr'] = array(
	'CiteThisPage' => array( 'Сайт' ),
);

/** Catalan (català) */
$specialPageAliases['ca'] = array(
	'CiteThisPage' => array( 'Citau', 'Citeu' ),
);

/** Min Dong Chinese (Mìng-dĕ̤ng-ngṳ̄) */
$specialPageAliases['cdo'] = array(
	'CiteThisPage' => array( '註' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'CiteThisPage' => array( 'Дош' ),
);

/** Czech (čeština) */
$specialPageAliases['cs'] = array(
	'CiteThisPage' => array( 'Citovat' ),
);

/** Danish (dansk) */
$specialPageAliases['da'] = array(
	'CiteThisPage' => array( 'Citer' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'CiteThisPage' => array( 'Zitierhilfe', 'Zitieren' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'CiteThisPage' => array( 'Sita' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'CiteThisPage' => array( 'Citěrowańska_pomoc' ),
);

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = array(
	'CiteThisPage' => array( 'ΠαραπομπήΑυτήΤηΣελίδα', 'Παραπομπή' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'CiteThisPage' => array( 'Citi' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'CiteThisPage' => array( 'Tsiteerimine' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'CiteThisPage' => array( 'یادکرد' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'CiteThisPage' => array( 'Viittaus' ),
);

/** French (français) */
$specialPageAliases['fr'] = array(
	'CiteThisPage' => array( 'Citer' ),
);

/** Franco-Provençal (arpetan) */
$specialPageAliases['frp'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Western Frisian (Frysk) */
$specialPageAliases['fy'] = array(
	'CiteThisPage' => array( 'Sitearje' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'CiteThisPage' => array( 'Cita', 'Citar' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'CiteThisPage' => array( 'Zitierhilf' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'CiteThisPage' => array( 'ציטוט_דף_זה', 'ציטוט' ),
);

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = array(
	'CiteThisPage' => array( 'Citiraj' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'CiteThisPage' => array( 'Citowanska_pomoc' ),
);

/** Xiang Chinese (湘语) */
$specialPageAliases['hsn'] = array(
	'CiteThisPage' => array( '建脚注' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'CiteThisPage' => array( 'Site' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'CiteThisPage' => array( 'Hivatkozás', 'Irodalomjegyzék' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'CiteThisPage' => array( 'Citation' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'CiteThisPage' => array( 'Kutip' ),
);

/** Igbo (Igbo) */
$specialPageAliases['ig'] = array(
	'CiteThisPage' => array( 'Dépùtà' ),
);

/** Ido (Ido) */
$specialPageAliases['io'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'CiteThisPage' => array( 'Cita' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'CiteThisPage' => array( 'このページを引用', '引用' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'CiteThisPage' => array( '이문서인용', '인용' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'CiteThisPage' => array( 'Zitteere' ),
);

/** Cornish (kernowek) */
$specialPageAliases['kw'] = array(
	'CiteThisPage' => array( 'Devynna' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'CiteThisPage' => array( 'MostrarManaderos' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'CiteThisPage' => array( 'Zitéierhellëf' ),
);

/** Literary Chinese (文言) */
$specialPageAliases['lzh'] = array(
	'CiteThisPage' => array( '引文' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'CiteThisPage' => array( 'Навод' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'CiteThisPage' => array( 'അവലംബം' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'CiteThisPage' => array( 'संदर्भद्या' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'CiteThisPage' => array( 'Petik_laman_ini', 'Petik' ),
);

/** Maltese (Malti) */
$specialPageAliases['mt'] = array(
	'CiteThisPage' => array( 'Iċċita' ),
);

/** Nāhuatl (Nāhuatl) */
$specialPageAliases['nah'] = array(
	'CiteThisPage' => array( 'Tlahtoa', 'Citar' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'CiteThisPage' => array( 'Siteringshjelp' ),
);

/** Low German (Plattdüütsch) */
$specialPageAliases['nds'] = array(
	'CiteThisPage' => array( 'Ziteerhelp' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'CiteThisPage' => array( 'Siteerhulpe' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'CiteThisPage' => array( 'Citeren' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'CiteThisPage' => array( 'Siter' ),
);

/** Occitan (occitan) */
$specialPageAliases['oc'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'CiteThisPage' => array( 'Cytuj' ),
);

/** Pashto (پښتو) */
$specialPageAliases['ps'] = array(
	'CiteThisPage' => array( 'درک' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Romanian (română) */
$specialPageAliases['ro'] = array(
	'CiteThisPage' => array( 'Citează' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'CiteThisPage' => array( 'Цитата' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'CiteThisPage' => array( 'उद्धृत' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'CiteThisPage' => array( 'Cita' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'CiteThisPage' => array( 'Citovať' ),
);

/** Slovenian (slovenščina) */
$specialPageAliases['sl'] = array(
	'CiteThisPage' => array( 'Navedi' ),
);

/** Albanian (shqip) */
$specialPageAliases['sq'] = array(
	'CiteThisPage' => array( 'Citim' ),
);

/** Serbian (Cyrillic script) (српски (ћирилица)‎) */
$specialPageAliases['sr-ec'] = array(
	'CiteThisPage' => array( 'Цитирај' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'CiteThisPage' => array( 'Citera' ),
);

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = array(
	'CiteThisPage' => array( 'Taja', 'Hakikisha' ),
);

/** Tetum (tetun) */
$specialPageAliases['tet'] = array(
	'CiteThisPage' => array( 'Sita' ),
);

/** Thai (ไทย) */
$specialPageAliases['th'] = array(
	'CiteThisPage' => array( 'อ้างอิง' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'CiteThisPage' => array( 'Sipiin' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'CiteThisPage' => array( 'KaynakGöster' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'CiteThisPage' => array( 'Цитата' ),
);

/** Urdu (اردو) */
$specialPageAliases['ur'] = array(
	'CiteThisPage' => array( 'حوالہ' ),
);

/** Venetian (vèneto) */
$specialPageAliases['vec'] = array(
	'CiteThisPage' => array( 'Cita' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'CiteThisPage' => array( 'Trích_dẫn' ),
);

/** Yiddish (ייִדיש) */
$specialPageAliases['yi'] = array(
	'CiteThisPage' => array( 'ציטירן' ),
);

/** Cantonese (粵語) */
$specialPageAliases['yue'] = array(
	'CiteThisPage' => array( '引用' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'CiteThisPage' => array( '引用此页面', '引用' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'CiteThisPage' => array( '引用' ),
);

==> mediawiki_1.27.7.orig.tar.gz: mediawiki-1.27.7/extensions/CiteThisPage/CiteThisPage.alias.php <==
<?php
/**
 * Aliases for Special:CiteThisPage
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'CiteThisPage' => array( 'CiteThisPage', 'Cite' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'CiteThisPage' => array( 'استشهاد' ),
);

/** Egyptian Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'CiteThisPage' => array( 'استشهاد' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'CiteThisPage' => array( 'উদ্ধৃতি' ),
);

/** Avaric (авар) */
$specialPageAliases['av'] = array(
	'CiteThisPage' => array( 'Цитата' ),
);

/** Bikol Central (Bikol Central) */
$specialPageAliases['bcl'] = array(
	'CiteThisPage' => array( 'Sambitón' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'CiteThisPage' => array( 'Цитиране' ),
);

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = array(
	'CiteThisPage' => array( 'یات_کورت' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'CiteThisPage' => array( 'Juhut' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'CiteThisPage' => array( 'Menegiñ' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'CiteThisPage' => array( 'Citiraj' ),
);

/** буряад (буряад) */
$specialPageAliases['bxr'] = array(
	'CiteThisPage' => array( 'Сайт' ),
);

/** Catalan (català) */
$specialPageAliases['ca'] = array(
	'CiteThisPage' => array( 'Citau', 'Citeu' ),
);

/** Min Dong Chinese (Mìng-dĕ̤ng-ngṳ̄) */
$specialPageAliases['cdo'] = array(
	'CiteThisPage' => array( '註' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'CiteThisPage' => array( 'Дош' ),
);

/** Czech (čeština) */
$specialPageAliases['cs'] = array(
	'CiteThisPage' => array( 'Citovat' ),
);

/** Danish (dansk) */
$specialPageAliases['da'] = array(
	'CiteThisPage' => array( 'Citer' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'CiteThisPage' => array( 'Zitierhilfe', 'Zitieren' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'CiteThisPage' => array( 'Sita' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'CiteThisPage' => array( 'Citěrowańska_pomoc' ),
);

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = array(
	'CiteThisPage' => array( 'ΠαραπομπήΑυτήΤηΣελίδα', 'Παραπομπή' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'CiteThisPage' => array( 'Citi' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'CiteThisPage' => array( 'Tsiteerimine' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'CiteThisPage' => array( 'یادکرد' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'CiteThisPage' => array( 'Viittaus' ),
);

/** French (français) */
$specialPageAliases['fr'] = array(
	'CiteThisPage' => array( 'Citer' ),
);

/** Arpitan (arpetan) */
$specialPageAliases['frp'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Western Frisian (Frysk) */
$specialPageAliases['fy'] = array(
	'CiteThisPage' => array( 'Sitearje' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'CiteThisPage' => array( 'Cita', 'Citar' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'CiteThisPage' => array( 'Zitierhilf' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'CiteThisPage' => array( 'ציטוט_דף_זה', 'ציטוט' ),
);

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = array(
	'CiteThisPage' => array( 'Citiraj' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'CiteThisPage' => array( 'Citowanska_pomoc' ),
);

/** Xiang Chinese (湘语) */
$specialPageAliases['hsn'] = array(
	'CiteThisPage' => array( '建脚注' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'CiteThisPage' => array( 'Site' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'CiteThisPage' => array( 'Hivatkozás', 'Irodalomjegyzék' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'CiteThisPage' => array( 'Citation' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'CiteThisPage' => array( 'Kutip' ),
);

/** Igbo (Igbo) */
$specialPageAliases['ig'] = array(
	'CiteThisPage' => array( 'Dépùtà' ),
);

/** Ido (Ido) */
$specialPageAliases['io'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'CiteThisPage' => array( 'Cita' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'CiteThisPage' => array( 'このページを引用', '引用' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'CiteThisPage' => array( '이문서인용', '인용' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'CiteThisPage' => array( 'Zitteere' ),
);

/** Cornish (kernowek) */
$specialPageAliases['kw'] = array(
	'CiteThisPage' => array( 'Devynna' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'CiteThisPage' => array( 'MostrarManaderos' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'CiteThisPage' => array( 'Zitéierhellëf' ),
);

/** Northern Luri (لۊری شومالی) */
$specialPageAliases['lrc'] = array(
	'CiteThisPage' => array( 'تیار_کئردئن_ئی_بألگە', 'تیارگە' ),
);

/** Literary Chinese (文言) */
$specialPageAliases['lzh'] = array(
	'CiteThisPage' => array( '引文' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'CiteThisPage' => array( 'Навод' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'CiteThisPage' => array( 'അവലംബം' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'CiteThisPage' => array( 'संदर्भद्या' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'CiteThisPage' => array( 'Petik_laman_ini', 'Petik' ),
);

/** Maltese (Malti) */
$specialPageAliases['mt'] = array(
	'CiteThisPage' => array( 'Iċċita' ),
);

/** Nāhuatl (Nāhuatl) */
$specialPageAliases['nah'] = array(
	'CiteThisPage' => array( 'Tlahtoa', 'Citar' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'CiteThisPage' => array( 'Siteringshjelp' ),
);

/** Low German (Plattdüütsch) */
$specialPageAliases['nds'] = array(
	'CiteThisPage' => array( 'Ziteerhelp' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'CiteThisPage' => array( 'Siteerhulpe' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'CiteThisPage' => array( 'Citeren' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'CiteThisPage' => array( 'Siter' ),
);

/** Occitan (occitan) */
$specialPageAliases['oc'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'CiteThisPage' => array( 'Cytuj' ),
);

/** Pashto (پښتو) */
$specialPageAliases['ps'] = array(
	'CiteThisPage' => array( 'درک' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = array(
	'CiteThisPage' => array( 'Citar' ),
);

/** Romanian (română) */
$specialPageAliases['ro'] = array(
	'CiteThisPage' => array( 'Citează' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'CiteThisPage' => array( 'Цитата' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'CiteThisPage' => array( 'उद्धृत' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'CiteThisPage' => array( 'Cita' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'CiteThisPage' => array( 'Citovať' ),
);

/** Slovenian (slovenščina) */
$specialPageAliases['sl'] = array(
	'CiteThisPage' => array( 'Navedi' ),
);

/** Albanian (shqip) */
$specialPageAliases['sq'] = array(
	'CiteThisPage' => array( 'Citim' ),
);

/** Serbian (Cyrillic script) (српски (ћирилица)‎) */
$specialPageAliases['sr-ec'] = array(
	'CiteThisPage' => array( 'Цитирај' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'CiteThisPage' => array( 'Citera' ),
);

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = array(
	'CiteThisPage' => array( 'Taja', 'Hakikisha' ),
);

/** Tetum (tetun) */
$specialPageAliases['tet'] = array(
	'CiteThisPage' => array( 'Sita' ),
);

/** Thai (ไทย) */
$specialPageAliases['th'] = array(
	'CiteThisPage' => array( 'อ้างอิง' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'CiteThisPage' => array( 'Sipiin' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'CiteThisPage' => array( 'KaynakGöster' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'CiteThisPage' => array( 'Цитата' ),
);

/** Urdu (اردو) */
$specialPageAliases['ur'] = array(
	'CiteThisPage' => array( 'حوالہ' ),
);

/** Venetian (vèneto) */
$specialPageAliases['vec'] = array(
	'CiteThisPage' => array( 'Cita' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'CiteThisPage' => array( 'Trích_dẫn' ),
);

/** Yiddish (ייִדיש) */
$specialPageAliases['yi'] = array(
	'CiteThisPage' => array( 'ציטירן' ),
);

/** Cantonese (粵語) */
$specialPageAliases['yue'] = array(
	'CiteThisPage' => array( '引用' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'CiteThisPage' => array( '引用此页面', '引用' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'CiteThisPage' => array( '引用' ),
);
